@@ -2,7 +2,9 @@
 
 set -e
 
-if [ -z "$DISABLE_AUTHENTICATION" ]; then
+if [ -n "$DISABLE_AUTHENTICATION" ]; then
+    OPTIONS="--no-auth $OPTIONS"
+else
     if [ ! -f "$PASSWORD_FILE" ]; then
         touch "$PASSWORD_FILE"
     fi
@@ -12,8 +14,6 @@ if [ -z "$DISABLE_AUTHENTICATION" ]; then
         echo "**WARNING** No user exists, please 'docker exec -it \$CONTAINER_ID create_user'"
         echo
     fi
-else
-    rm -f "$PASSWORD_FILE"
 fi
 
 exec rest-server --path "$DATA_DIRECTORY" $OPTIONS
